from unittest import mock

from tatt.vendors.amazon import Transcriber



def test_transcriber_instantiate():
    filepath = '/Users/zev/tester.mp3'
    t = Transcriber(filepath)
    assert str(t.filepath) == filepath
    assert t.basename == 'tester.mp3'
    assert t.media_file_uri == (
        f'https://s3-us-east-1.amazonaws.com/tatt-media-amazon/tester.mp3'
            )


@mock.patch('tatt.vendors.amazon.tr.get_transcription_job')
def test_transcriber_retrieve(get_transcription_job):
    filepath = '/Users/zev/tester.mp3'
    job_name = '4db6808e-a7e8-4d8d-a1b7-753ab97094dc'
    t = Transcriber.retrieve_transcript(job_name)
    get_transcription_job.assert_called_with(TranscriptionJobName=job_name)


def test_transcriber_get_transcription_jobs():
    result = Transcriber.get_transcription_jobs()
    assert result


def test_transcriber_retrieve_transcript():
    jobs = Transcriber.get_transcription_jobs()
    for j in jobs:
        if j['status'].lower() == 'completed':
            to_get = j['name']
            break
    transcript = Transcriber.retrieve_transcript(to_get)
    assert transcript == {'jobName': 'abcd.mp3', 'accountId': '416321668733', 'results': {'transcripts': [{'transcript': 'Hello there.'}], 'items': [{'start_time': '0.0', 'end_time': '0.35', 'alternatives': [{'confidence': '0.8303', 'content': 'Hello'}], 'type': 'pronunciation'}, {'start_time': '0.35', 'end_time': '0.76', 'alternatives': [{'confidence': '1.0000', 'content': 'there'}], 'type': 'pronunciation'}, {'alternatives': [{'confidence': None, 'content': '.'}], 'type': 'punctuation'}]}, 'status': 'COMPLETED'}



from tatt.vendors import SERVICES


def test_services():
    for service in SERVICES.values():
        assert hasattr(service, 'Transcriber')
        assert hasattr(service, 'NAME')
        assert hasattr(service.Transcriber, 'cost_per_15_seconds')



import abc
import os
from pathlib import PurePath
from typing import List

from tatt import exceptions


class TranscriberBaseClass:

    __metaclass__ = abc.ABCMeta

    def __init__(self, filepath):
        self._setup()
        self.filepath = PurePath(filepath)
        self.basename = str(os.path.basename(self.filepath))

    @property
    @abc.abstractmethod
    def no_config_error_message(self):
        """
        This must be defined as a class attribute, to be printed when raising
        such an error.
        """
        pass

    @property
    @abc.abstractmethod
    def cost_per_15_seconds(self):
        """This must be defined as a class attribute."""
        pass

    @classmethod
    def _setup(cls):
        if not cls.check_for_config():
            raise exceptions.ConfigError(cls.no_config_error_message)

    @staticmethod
    @abc.abstractmethod
    def check_for_config() -> bool:
        pass

    @abc.abstractmethod
    def transcribe(self) -> str:
        """
        This should do any required logic, 
        then call self._request_transcription.
        It should return the job_name.
        """
        pass

    @abc.abstractmethod
    def _request_transcription(self) -> str:
        """Returns the job_name"""
        pass

    @classmethod
    @abc.abstractmethod
    def retrieve_transcript(transcription_job_name: str) -> dict:
        pass

    @classmethod
    @abc.abstractmethod
    def get_transcription_jobs() -> List[dict]:
        pass

